@@ -1,5 +1,5 @@
 // -*- C++ -*-
-/* Copyright (C) 1989, 1990, 1991, 1992, 2002, 2003
+/* Copyright (C) 1989, 1990, 1991, 1992, 2002, 2003, 2007, 2008, 2009
    Free Software Foundation, Inc.
      Written by James Clark (jjc@jclark.com)
 
@@ -7,17 +7,16 @@ This file is part of groff.
 
 groff is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free
-Software Foundation; either version 2, or (at your option) any later
-version.
+Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
 groff is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
 FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
-You should have received a copy of the GNU General Public License along
-with groff; see the file COPYING.  If not, write to the Free Software
-Foundation, 51 Franklin St - Fifth Floor, Boston, MA 02110-1301, USA. */
+You should have received a copy of the GNU General Public License
+along with this program. If not, see <http://www.gnu.org/licenses/>. */
 
 #include "eqn.h"
 #include "pbox.h"
@@ -93,7 +92,8 @@ int sqrt_box::compute_metrics(int style)
   printf(".de " TEMP_MACRO "\n"
 	 ".nr " SQRT_WIDTH_FORMAT
 	 " 0\\w" DELIMITER_CHAR "\\*[" SQRT_STRING_FORMAT "]" DELIMITER_CHAR "\n"
-	 ".if \\\\n[rst]-\\\\n[rsb]-%dM<\\n[" TEMP_REG "]"
+	 ".if \\\\n[rst]"
+	 "&(\\\\n[rst]-\\\\n[rsb]-%dM<\\n[" TEMP_REG "])"
 	 "&(\\\\n[.ps]<\\n[" MAX_SIZE_REG "]) \\{"
 	 ".ps +1\n"
 	 "." TEMP_MACRO "\n"
@@ -150,21 +150,28 @@ int sqrt_box::compute_metrics(int style)
 
 void sqrt_box::output()
 {
-  printf("\\Z" DELIMITER_CHAR);
-  printf("\\s[\\n[" SMALL_SIZE_FORMAT "]u]", uid);
-  printf("\\v'-\\n[" SUP_RAISE_FORMAT "]u'", uid);
-  printf("\\*[" SQRT_STRING_FORMAT "]", uid);
-  printf("\\s[\\n[" SIZE_FORMAT "]u]", uid);
-  printf(DELIMITER_CHAR);
+  if (output_format == troff) {
+    printf("\\Z" DELIMITER_CHAR);
+    printf("\\s[\\n[" SMALL_SIZE_FORMAT "]u]", uid);
+    printf("\\v'-\\n[" SUP_RAISE_FORMAT "]u'", uid);
+    printf("\\*[" SQRT_STRING_FORMAT "]", uid);
+    printf("\\s[\\n[" SIZE_FORMAT "]u]", uid);
+    printf(DELIMITER_CHAR);
 
-  printf("\\Z" DELIMITER_CHAR);
-  printf("\\h'\\n[" WIDTH_FORMAT "]u-\\n[" WIDTH_FORMAT "]u"
-	 "+\\n[" SQRT_WIDTH_FORMAT "]u/2u'",
-	 uid, p->uid, uid);
-  p->output();
-  printf(DELIMITER_CHAR);
+    printf("\\Z" DELIMITER_CHAR);
+    printf("\\h'\\n[" WIDTH_FORMAT "]u-\\n[" WIDTH_FORMAT "]u"
+	   "+\\n[" SQRT_WIDTH_FORMAT "]u/2u'",
+	   uid, p->uid, uid);
+    p->output();
+    printf(DELIMITER_CHAR);
 
-  printf("\\h'\\n[" WIDTH_FORMAT "]u'", uid);
+    printf("\\h'\\n[" WIDTH_FORMAT "]u'", uid);
+  }
+  else if (output_format == mathml) {
+    printf("<msqrt>");
+    p->output();
+    printf("</msqrt>");
+  }
 }
 
 void sqrt_box::debug_print()
